hypigu: Compute the Igusa local zeta function associated with hyperplane arrangements
=====================================================================================

Description
-----------

SageMath package that provides functions to compute the Igusa local zeta function associated with hyperplane arrangements

License
-------

MIT

Upstream Contact
----------------

- https://pypi.org/project/hypigu/
- https://github.com/passagemath/passagemath-pkg-hypigu
